# Project: demo of interactive graphics with esetVis, ggvis and shiny
# 
# Author: Laure Cougnaud
###############################################################################

# run the analysis as previously, this need to be done once for each dataset
# objects can be stored and reloaded
# useful for the fast demonstration, otherwise not needed

cat("ui \n")

setwd("/home/lcougnaud/git/useR2015/visualizationsGenomicData_R_conference/presentation/shinyApp")

library(shiny)
library(esetVis)

createAnalysis <- FALSE

if(!"./objects" %in% list.dirs())	dir.create("objects")
myObjectPath <- function(x) paste0("./objects/", x)

spectralMapALLPath <- myObjectPath("spectralMapALL.RData")
tsneALLPath <- myObjectPath("tsneALL.RData")
ldaALLPath <- myObjectPath("ldaALL.RData")

if(!exists("ALL"))	load("../objects/ALL.RData")

if(createAnalysis){
	
	# load ALL dataset
	system.time(spectralMapALL <- esetSpectralMap(eset = ALL, returnAnalysis = TRUE))
	save(spectralMapALL, file = spectralMapALLPath)
	
	system.time(tsneALL <- esetTsne(eset = ALL, returnAnalysis = TRUE))
	save(tsneALL, file = tsneALLPath)
	
	system.time(ldaALL <- esetLda(eset = ALL, ldaVar = "BT", returnAnalysis = TRUE))
	save(ldaALL, file = ldaALLPath)
	
}else{
	if(!exists("spectralMapALL"))	load(spectralMapALLPath)
	if(!exists("tsneALL"))	load(tsneALLPath)	
	if(!exists("ldaALL"))	load(ldaALLPath)
}

topElementsUI <- function(type = c("gene", "sample")){
	
#	res <- list(
#		#h3(type),
#		fluidRow(
#			column(6, helpText("Number")),
#			column(6, 
#				numericInput(paste0("nTop", type), "", value = 10,
#					min = 0, max = nrow(ALL), step = 1)
#			)
#		),
#		fluidRow(
#			column(6, helpText("Variable")),
#			column(6, 
#				selectInput(paste0("var", type), label = "",
#					choices = fvarLabels(ALL), selected = "SYMBOL")
#			)
#		)
#	)
	
	res <- list(fluidRow(
		column(6, 
			numericInput(paste0("nTop", type), paste("nTop", type), 
				value = 10, min = 0, max = nrow(ALL), step = 1)
		),
		column(6, 
			selectInput(paste0("var", type), label = paste("Variable", type),
				choices = switch(type, gene = fvarLabels, sample = varLabels)(ALL), 
				selected = switch(type, gene = "SYMBOL", sample = "cod"))
		)
	))
	
	return(res)
}
	

shinyUI(
		
	fluidPage(	
		
		h1("Exploratory analysis of genomic data with esetVis"),
		
		br(),
			
		sidebarLayout(
				
			sidebarPanel({
				
				sidebarPanelElements <- c(list(
					
					h3("Plot type"),
					selectInput("typePlot", label = "",
						choices = 
							list("spectral map" = 1,
								"tsne" = 2, 
								"linear discriminant analysis (BT variable)" = 3
						)
					),
					
					h3("Sample annotation"),
					selectInput("colPlot", label = "Color",
						choices = varLabels(ALL), selected = "BT"),
					# Continuous variable cannot be mapped to shape
					selectInput("shapePlot", label = "Shape",
						choices = varLabels(ALL)[varLabels(ALL) != "age"], selected = "sex"),
					selectInput("sizePlot", label = "Size",
						choices = varLabels(ALL), selected = "age")

					#h3("Label outlying features")
	
				), #topElementsUI("gene"), topElementsUI("sample"),
				
					list(
					
						h3("Tooltip"),
					
						selectInput("tooltipExtraVars", label = "Covariates used for labelling",
							choices = varLabels(ALL), multiple = TRUE)
					)
		
				)
	
			}),
		
			mainPanel(
					
				ggvisOutput("esetPlotGGvis"),uiOutput("esetPlotGGvis_ui")	
					
				# for ggplot2
				#plotOutput("esetPlot", width = "600px", height = "600px")
						
			)##
	
		)

	)

)
